@@ -20,13 +20,14 @@ use Capture::Tiny qw( capture );
 use Carp          qw( croak   );
 use Mac::PropertyList;
 
-our $VERSION = '0.7956';
+our $VERSION = '0.7957';
 our @EXPORT  = qw(
     fsysctl
     nsysctl
     plist
     sw_vers
     system_profiler
+    vm_stat
 );
 
 sub plist {
@@ -52,15 +53,77 @@ sub plist {
     return $prop->as_perl;
 }
 
+#
+# TODO: https://github.com/aosm/system_cmds/blob/master/vm_stat.tproj/vm_stat.c
+#
+sub vm_stat {
+    my $success;
+    my($out, $error) = capture {
+        $success = ! system q{/usr/bin/vm_stat};
+    };
+
+    warn "vm_stat: $error\n"                   if $error;
+    croak "vm_stat call failed!"               if ! $success;
+    croak "vm_stat didn't generate any output" if ! $out;
+
+    my @lines     = split m{\n+}, $out;
+    my $page_size = shift @lines;
+
+    if ( $page_size =~ m{
+            \QMach Virtual Memory Statistics: (page size of\E
+                \s (.+?) \s
+            bytes\)
+        }xms
+    ) {
+        $page_size = $1;
+    }
+    else {
+        croak "Unable to determine page size from input";
+    }
+
+    pop @lines; # some junk info line
+
+    my %rv;
+
+    for my $line ( @lines ) {
+        my($k, $v) = split m{[:]}xms, $line, 2;
+        $_ = __PACKAGE__->trim( $_ ) for $k, $v;
+        $k =~ s{ \A ["']    }{}xms;
+        $k =~ s{    ["'] \z }{}xms;
+        $k =~ s{    [\s\-]  }{_}xmsg;
+        $v =~ s{    [.]  \z }{}xms;
+        $rv{lc $k} = $v;
+    }
+
+    $rv{page_size}   = $page_size;
+
+    $rv{memory_free} = (  $rv{pages_speculative}
+                        + $rv{pages_free}
+                        )
+                        * $rv{page_size};
+
+    $rv{memory_used} = (  $rv{pages_wired_down}
+                        + $rv{pages_inactive}
+                        + $rv{pages_active}
+                        )
+                        * $rv{page_size};
+    return %rv;
+}
+
 sub system_profiler {
     # SPSoftwareDataType -> os version. user
     # SPHardwareDataType -> cpu
     # SPMemoryDataType   -> ram
     my(@types) = @_;
+
+    my $success;
     my($out, $error) = capture {
-        system system_profiler => '-xml', (@types ? @types : ())
+        $success = ! system '/usr/sbin/system_profiler' => '-xml', (@types ? @types : ())
     };
 
+    croak "system_profiler(@types) failed!"                      if ! $success;
+    croak "system_profiler(@types) did not generate any output!" if ! $out;
+
     my $raw = plist( $out );
 
     my %rv;
@@ -75,10 +138,17 @@ sub system_profiler {
 }
 
 sub sw_vers {
-    my($out, $error) = capture { system 'sw_vers' };
+    my $success;
+    my($out, $error) = capture {
+        $success = ! system '/usr/bin/sw_vers';
+    };
+
     $_ = __PACKAGE__->trim( $_ ) for $out, $error;
-    croak "Unable to capture `sw_vers`: $error" if $error;
-    return map { split m{:\s+?}xms, $_ } split m{\n}xms, $out;
+
+    croak "Unable to capture `sw_vers`: $error" if $error || ! $success;
+
+    return map { split m{:\s+?}xms, $_ }
+                 split m{\n}xms, $out;
 }
 
 sub fsysctl {
@@ -98,7 +168,12 @@ sub nsysctl {
 
 sub _sysctl {
     my($key) = @_;
-    my($out, $error) = capture { system sysctl => $key };
+
+    my $success;
+    my($out, $error) = capture {
+        $success = ! system '/usr/sbin/sysctl' => $key;
+    };
+
     my %rv;
     if ( $out ) {
         foreach my $row ( split RE_SYSCTL_SPLIT, $out ) {
@@ -114,15 +189,17 @@ sub _sysctl {
     $error = __PACKAGE__->trim( $error ) if $error;
 
     return {
-        value => $total > 1 ? { %rv } : $rv{ $key },
-        error => $error,
-        bogus => $error ? _sysctl_not_exists( $error ) : 0,
+        value   => $total > 1 ? { %rv } : $rv{ $key },
+        error   => $error,
+        bogus   => $error ? _sysctl_not_exists( $error ) : 0,
+        success => $success,
     };
 }
 
 sub _parse_sysctl_row {
     my($row, $key) = @_;
     my(undef, $name, $value) = split RE_SYSCTL_ROW, $row, 2;
+
     if ( ! defined $value || $value eq q{} ) {
         croak sprintf q(Can't happen: No value in output for property )
                      . q('%s' inside row '%s' collected from key '%s'),
@@ -130,6 +207,7 @@ sub _parse_sysctl_row {
                         $row,
                         $key;
     }
+
     return map { __PACKAGE__->trim( $_ ) } $name, $value;
 }
 
@@ -156,8 +234,8 @@ Sys::Info::Driver::OSX - OSX driver for Sys::Info
 
 =head1 DESCRIPTION
 
-This document describes version C<0.7956> of C<Sys::Info::Driver::OSX>
-released on C<11 May 2013>.
+This document describes version C<0.7957> of C<Sys::Info::Driver::OSX>
+released on C<13 May 2013>.
 
 This is the main module in the C<OSX> driver collection.
 
@@ -183,6 +261,10 @@ System call to system_profiler.
 
 System call to sw_vers.
 
+=head2 vm_stat
+
+System call to vm_stat
+
 =head2 plist
 
 Converts a file or raw plist data into a Perl structure.
@@ -198,6 +280,6 @@ Copyright 2010 - 2013 Burak Gursoy. All rights reserved.
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.16.2 or,
+it under the same terms as Perl itself, either Perl version 5.12.4 or,
 at your option, any later version of Perl 5 you may have available.
 =cut
